@@ -1,30 +1,16 @@
-import sys
-
-from Acquisition import Explicit
+from ..browser.formhelper import AddForm
+from ..browser.formhelper import EditForm
+from ..browser.formhelper import NullAddForm
 from OFS.SimpleItem import SimpleItem
-from ZODB.POSException import ConflictError
-
-from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
-
-from zope.interface import Interface, implements
-from zope.component import adapts
-
-from zope.publisher.interfaces.browser import IBrowserView
-
-from plone.portlets.interfaces import IPortletDataProvider
+from plone.app.portlets.interfaces import IDeferredPortletRenderer
 from plone.portlets.interfaces import IPortletAssignment
 from plone.portlets.interfaces import IPortletRenderer
-from plone.portlets.interfaces import IPortletManager
+from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
+from zope.container.contained import Contained
+from zope.interface import implementer
 
-from plone.app.portlets.interfaces import IDeferredPortletRenderer
-
-from zope.app.container.contained import Contained
-
-# Convenience imports
-from plone.app.portlets.browser.formhelper import AddForm
-from plone.app.portlets.browser.formhelper import NullAddForm
-from plone.app.portlets.browser.formhelper import EditForm
 
+@implementer(IPortletAssignment)
 class Assignment(SimpleItem, Contained):
     """Base class for assignments.
 
@@ -32,30 +18,28 @@ class Assignment(SimpleItem, Contained):
     may
     """
 
-    implements(IPortletAssignment)
-
-    __name__ = ''
+    __name__ = ""
 
     @property
     def id(self):
-        return getattr(self, '__name__', '')
+        return getattr(self, "__name__", "")
 
     @property
     def title(self):
         return self.id
 
     def available(self, context, request):
-        """By default, this portlet is always available
-        """
+        """By default, this portlet is always available"""
         return True
 
     @property
     def data(self):
-        """Make the assignment itself represent the data object that is being rendered.
-        """
+        """Make the assignment itself represent the data object that is being rendered."""
         return self
 
-class Renderer(Explicit):
+
+@implementer(IPortletRenderer)
+class Renderer:
     """Base class for portlet renderers.
 
     You must override render() to return a string to render. One way of
@@ -69,8 +53,6 @@ class Renderer(Explicit):
     as your source code file.
     """
 
-    implements(IPortletRenderer)
-
     def __init__(self, context, request, view, manager, data):
         self.context = context
         self.request = request
@@ -83,15 +65,17 @@ class Renderer(Explicit):
         pass
 
     def render(self):
-        raise NotImplementedError("You must implement 'render' as a method "
-                                  "or page template file attribute")
+        raise NotImplementedError(
+            "You must implement 'render' as a method " "or page template file attribute"
+        )
 
     @property
     def available(self):
-        """By default, portlets are available
-        """
+        """By default, portlets are available"""
         return True
 
+
+@implementer(IDeferredPortletRenderer)
 class DeferredRenderer(Renderer):
     """provide defer functionality via KSS
 
@@ -99,12 +83,12 @@ class DeferredRenderer(Renderer):
 
     """
 
-    implements(IDeferredPortletRenderer)
-
-    render_preload = ViewPageTemplateFile('deferred_portlet.pt')
+    render_preload = ViewPageTemplateFile("deferred_portlet.pt")
 
     def render_full(self):
-        raise NotImplemented, "You must implement 'render_full' as a method or page template file attribute"
+        raise NotImplemented(
+            "You must implement 'render_full' as a method or page template file attribute"
+        )
 
     def render(self):
         """render the portlet
@@ -115,4 +99,3 @@ class DeferredRenderer(Renderer):
             return self.render_preload()
         else:
             return self.render_full()
-
